==> cinepaint-0.21-1.tar.gz: cinepaint-0.21-1/plug-ins/bracketing_to_hdr/gui/gui_rest.hpp <==
/*
 * gui/gui_rest.hpp  --  Part of the CinePaint plug-in "Bracketing_to_HDR"
 *
 * Copyright (c) 2005-2006  Hartmut Sbosny  <hartmut.sbosny@gmx.de>
 *
 * LICENSE:
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
/** 
  @file  gui_rest.hpp
  
  Some things we declare in FLUID (-> "gui.h"), but code the implementation
   outside of FLUID in "gui_rest.cpp" (i.e. not in "gui.cxx") . And some 
   things used in FLUID refer to "gui.h" stuff, but their declarations are 
   easier to do outside of FLUID. These things are declared here.
*/
#ifndef gui_rest_hpp
#define gui_rest_hpp

#include "../core/EventReceiver.hpp"

/*****************************************************************************
  non-member functions used in gui.cxx (resp. gui.fl)
******************************************************************************/
void save_response_curves_dialog (br::Br2Hdr::WhichCurves, int channel_like);
bool load_response_curve         (int channel, const char* fname);
void load_response_curve_dialog  (int channel);
void load_all_response_curves_dialog();


/**+**************************************************************************
  @class  MainWinMenubarWatcher

  Private helper object of MainWinClass to handle de/activations of menubar
   items accordingly to state changes of Br2Hdr::Instance(). As EventReceiver
   inheritor the Ctor logs-in automatically in the Event-Distributor of 
   Br2Hdr::Instance() and the (virtual) handle_Event() routine gets all
   Event-messages then. There we do the de|activation stuff. 
  An alternative would be to inherite MainWinClass from EventReceiver like
   ResponsePlotWinClass does.  
******************************************************************************/
class MainWinMenubarWatcher : public br::EventReceiver
{
public:
    MainWinMenubarWatcher()  {}
    void handle_Event (br::Br2Hdr::Event);  // virtual inheritance
};



#endif  // gui_rest_hpp

// END OF FILE

==> cinepaint_0.21-2.orig.tar.gz: cinepaint-0.21-2/plug-ins/bracketing_to_hdr/gui/gui_rest.hpp <==
/*
 * gui_rest.hpp  --  Part of the CinePaint plug-in "Bracketing_to_HDR"
 *
 * Copyright (c) 2005-2006  Hartmut Sbosny  <hartmut.sbosny@gmx.de>
 *
 * LICENSE:
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
/** 
  @file  gui_rest.hpp
  
  Some things we declare in FLUID (-> "gui.h"), but code the implementation
   outside of FLUID in "gui_rest.cpp" (i.e. not in "gui.cxx") . And some 
   things used in FLUID refer to "gui.h" stuff, but their declarations are 
   easier to do outside of FLUID. These things are declared here.
*/
#ifndef gui_rest_hpp
#define gui_rest_hpp


#include "EventReceiver.hpp"


/*****************************************************************************
  non-member functions used in gui.cxx (resp. gui.fl)
******************************************************************************/
void save_response_curves_dialog (br::Br2Hdr::WhichCurves, int channel_like);
bool load_response_curve         (int channel, const char* fname);
void load_response_curve_dialog  (int channel);
void load_all_response_curves_dialog();


/**+**************************************************************************
  @class  MainWinMenubarWatcher

  Private helper object of MainWinClass to handle de/activations of menubar
   items accordingly to state changes of Br2Hdr::Instance(). As EventReceiver
   inheritor the Ctor logs-in automatically in the Event-Distributor of 
   Br2Hdr::Instance() and the (virtual) handle_Event() routine gets all
   Event-messages then. There we do the de|activation stuff. 
  An alternative would be to inherite MainWinClass from EventReceiver like
   ResponsePlotWinClass does.  
******************************************************************************/
class MainWinMenubarWatcher : public br::EventReceiver
{
public:
    MainWinMenubarWatcher()  {}
    void handle_Event (br::Br2Hdr::Event);  // virtual inheritance
};


#endif  // gui_rest_hpp

// END OF FILE
